---
title: Composio
sidebarTitle: Composio
---

<img src="/static/img/ecosystem-composio.png" style={{ width: '40%' }} alt="Composio Logo"/>

Composio empowers AI agents to seamlessly connect with external tools, Apps, and APIs to perform actions and receive triggers. With built-in support for AG2, Composio enables the creation of highly capable and adaptable AI agents that can autonomously execute complex tasks and deliver personalized experiences.

- [Composio + AG2 Documentation with Code Examples](https://docs.composio.dev/framework/autogen)
